@@ -4,7 +4,7 @@ use anyhow::Result;
 
 #[derive(Clap)]
 #[clap(
-    version = "0.2.1",
+    version = "0.3.0",
     author = "ryoo14 <anana12185@gmail.com",
     about = "Manage working dir",
 )]
@@ -21,6 +21,8 @@ enum SubCommand {
     List(List),
     #[clap(about = "Create working dir")]
     Create(Create),
+    #[clap(about = "Clone Github repository")]
+    Get(Get),
 }
 
 #[derive(Clap)]
@@ -39,6 +41,12 @@ struct Create {
     targetdir_path: String,
 }
 
+#[derive(Clap)]
+// clone github repository
+struct Get {
+    repository: String,
+}
+
 fn main() -> Result<()> {
     let opts: Opts = Opts::parse();
     let wh = WorkHub::new()?;
@@ -63,6 +71,16 @@ fn main() -> Result<()> {
                 },
             }
         },
+        SubCommand::Get(g) => {
+            match wh.get(&g.repository) {
+                Ok(_) => {
+                    println!("Successfully cloned {}", &g.repository);
+                },
+                Err(e) => {
+                    println!("{}", e);
+                },
+            }
+        }
     }
     Ok(())
 }
